@@ -18,7 +18,7 @@ read.track.stats <- function(filename, mnemonics = NULL,
   }
   stats$label <- relevel.mnemonics(stats$label, mnemonics)
   stats <- rename.tracks(stats, ...)
-  
+
   stats
 }
 
@@ -27,15 +27,14 @@ read.gmtk.track.stats <- function(filename, mnemonics = NULL,
   means <- parse.gmtk.means(filename)
   covars <- parse.gmtk.covars(filename)
   data <- merge.gmtk.track.stats(means, covars)
-  
+
   data$label <- relevel.mnemonics(data$label, mnemonics)
   data <- rename.tracks(data, ...)
   data <- covar2sd(data)
-  
+
   data
 }
 
-
 merge.gmtk.track.stats <- function(means, covars) {
   if (!all(means$trackname[1:nrow(covars)] == covars$trackname)) {
     stop("Track ordering different between means and covars!")
@@ -44,7 +43,7 @@ merge.gmtk.track.stats <- function(means, covars) {
     stats <- subset(means, select=-value)
     stats$mean <- means$value
     stats$covar <- covars$value
-    
+
     stats
   }
 }
@@ -56,14 +55,61 @@ is.hierarchical.gmtk <- function(filename) {
   hierarchical
 }
 
+##' returns whether the file is both hierarchical and uses the
+##' hierarchy (has more than 1 subseg)
+##'
+##' <details>
+##' @title 
+##' @param filename 
+##' @return boolean 
+##' @author MICHAEL M. HOFFMAN
+is.truly.hierarchical.gmtk <- function(filename) {
+  lines <- readLines(filename)
+  hierarchical <- FALSE
+
+  matches <- grep("^seg_subseg $", lines)
+
+  # in new versions of Segway, subseg is always used, but it has
+  # cardinality 1. this assumes a GMTK-generated parameter file
+  if (length(matches) > 0) {
+    stopifnot(length(matches) == 1)
+    if (strsplit(lines[matches[1]+2], " ")[[1]][2] > 1)
+      hierarchical <- TRUE
+  }
+
+  hierarchical
+}
+
+regex.trailing.0 <- "_0$"
+
+##' eliminates trailing _0 if every label ends with that
+##'
+##' <details>
+##' @title simplify.labels
+##' @param labels (factor)
+##' @return factor
+##' @author Michael M. Hoffman
+simplify.labels <- function(labels) {
+  labels.levels <- levels(labels)
+
+  num.first.subsegs <- sum(grepl(regex.trailing.0, labels.levels))
+
+  # if they all end in _0
+  if (length(labels.levels) == num.first.subsegs) {
+    levels(labels) <- gsub(regex.trailing.0, "", labels.levels)
+  }
+
+  labels
+}
+
 parse.gmtk.means <- function(filename, hierarchical =
                              is.hierarchical.gmtk(filename)) {
   ## hierarchical:
   ##   TRUE: parse the params file expecting a hierarchical format
   ##   FALSE: parse the params file as a normal format
-  
+
   lines <- readLines(filename)
-  
+
   if (hierarchical) {
     pattern <- "^mean_seg([^_ ]+)_subseg([^_ ]+)_([^ ]+) 1 (.*)"
     replacement <- "\\1_\\2\t\\3\t\\4"
@@ -71,7 +117,7 @@ parse.gmtk.means <- function(filename, hierarchical =
     pattern <- "^mean_seg([^_ ]+)_([^ ]+) 1 (.*)"
     replacement <- "\\1\t\\2\t\\3"
   }
-  
+
   start <- grep("^% means$", lines) + 1
   lines.norm <- lines[start:length(lines)]
 
@@ -81,12 +127,13 @@ parse.gmtk.means <- function(filename, hierarchical =
 
   reformulated <- gsub(pattern, replacement, lines.interesting, perl = TRUE)
   writeLines(reformulated, anonfile)
-  
+
   means <- read.delim(anonfile, header = FALSE,
                       col.names = c("label", "trackname", "value"),
                       colClasses = c("factor", "factor", "numeric"))
   close(anonfile)
 
+  means$label <- simplify.labels(means$label)
   means
 }
 
@@ -102,7 +149,7 @@ parse.gmtk.covars <- function(filename) {
   reformulated <- gsub("^covar_([^ ]+) 1 (.*)",
                       "\\1\t\\2", lines.interesting, perl = TRUE)
   writeLines(reformulated, anonfile)
-  
+
   covars <- read.delim(anonfile, header = FALSE,
                        col.names = c("trackname", "value"),
                        colClasses = c("factor", "numeric"))
@@ -111,16 +158,18 @@ parse.gmtk.covars <- function(filename) {
   covars
 }
 
-## You should probably normalize with normalize.track.stats() first
+## You should probably normalize with normalize.track.stats() before
+## calling this.
 generate.mnemonics <- function(stats, hierarchical = FALSE, clust.func = hclust, ...) {
   if (!is.array(stats)) {
     stats <- as.stats.array(stats)
   }
-  
-  stats.mean <- t(stats[, , "mean"])
+
+  stats.mean <- t(stats[,,"mean"])
+
   dist.func <- if (hierarchical) hierarchical.dist else dist
   hclust.col <- clust.func(dist.func(stats.mean))
-  
+
   cut.height <- mean(range(hclust.col$height))
   stems <- (cutree(hclust.col, h = cut.height) - 1)[hclust.col$order]
   stems.reorder <- as.integer(factor(stems, levels = unique(stems))) - 1
@@ -148,7 +197,7 @@ rename.tracks <- function(stats, patterns = NULL, replacements = NULL,
   if (!is.data.frame(stats)) {
     stop("rename.tracks expected stats as data.frame")
   }
-  
+
   tracknames <- levels(stats$trackname)
   # Apply translation table substitutions
   if (!is.null(translation)) {
@@ -168,7 +217,7 @@ rename.tracks <- function(stats, patterns = NULL, replacements = NULL,
     }
   }
   levels(stats$trackname) <- tracknames
-  
+
   stats
 }
 
@@ -200,13 +249,13 @@ normalize.track.stats <- function(stats, cov = FALSE, sd.scale = TRUE) {
   if (!is.array(stats)) {
     stop("normalize.track.stats expected stats in array format!")
   }
-  
+
   ## Normalize mean
   means <- stats[, , "mean"]
   means.range <- t(apply(means, 1, range))
   means.min <- means.range[, 1]
   means.max <- means.range[, 2]
-  stats[, , "mean"] <- (means - means.min) / (means.max - means.min) 
+  stats[, , "mean"] <- (means - means.min) / (means.max - means.min)
 
   if ("sd" %in% dimnames(stats)[[3]]) {
     sds <- stats[, , "sd"]
@@ -249,7 +298,7 @@ normalize.binary.track.stats <- function(stats, cov = FALSE) {
 
 hierarchical.dist <- function(mat) {
   ## Returns a distance matrix, accomodating a hierarchical model
-  
+
   ## Hierarchy is denoted in the rownames, with "a_b" or "a.b"
   ## specifying a's child, b
   ## All nodes of a given level must have the same number of children
@@ -266,10 +315,10 @@ hierarchical.dist <- function(mat) {
     ## Convert the list of arrays to a single array,
     ##   since all depths are the same
     levels.mat <- matrix(unlist(levels.tokens), ncol = depth, byrow = TRUE)
-    
+
     mat.dist <- as.matrix(dist(mat))
     dist.thresh <- max(mat.dist) + 1  # Separate hierarchy levels this far
-    
+
     for (row.i in 1:nrow(mat)) {
       diff.rows <- rep(FALSE, nrow(mat))
       for (depth.i in 1:(depth - 1)) {
@@ -287,9 +336,9 @@ hierarchical.dist <- function(mat) {
 }
 
 panel.track.stats <-
-  function(x, y, z, subscripts, at = pretty(z), sds = NULL, 
-           ncolors = 2, threshold = FALSE, sd.shape = "box", 
-           panel.fill = "mean", box.fill = "gradient", 
+  function(x, y, z, subscripts, at = pretty(z), sds = NULL,
+           ncolors = 2, threshold = FALSE, sd.shape = "box",
+           panel.fill = "mean", box.fill = "gradient",
            sd.box.size = 0.4, sd.scale = 1, sd.line.size = 0.18,
            panel.outline = FALSE, horizontal.sd = TRUE, ...)
 {
@@ -302,7 +351,7 @@ panel.track.stats <-
   } else {
     sds <- as.numeric(sds)[subscripts]
   }
-  
+
   z.low <- z - sds
   z.high <- z + sds
   if (threshold) {
@@ -323,10 +372,10 @@ panel.track.stats <-
     col.mean <- zcol[i]
     z.range <- seq(from = z.low[i], to = z.high[i], length = ncolors)
     col.gradient <- level.colors(z.range, at = at, ...)
-    
+
     panel.offsets <- seq(from = - 0.5, by = 1 / ncolors, length = ncolors)
     panel.grad.size <- 1 / ncolors
-    box.offsets <- seq(from = - sd.size / 2, by = sd.size / ncolors, 
+    box.offsets <- seq(from = - sd.size / 2, by = sd.size / ncolors,
                        length = ncolors)
     box.grad.size <- sd.size / ncolors
 
@@ -365,7 +414,7 @@ panel.track.stats <-
                 default.units = "native",
                 gp = gpar(col = NA, fill = col.mean))
     } else if (panel.fill == "gradient") {
-      grid.rect(x = xs, y = ys, height = panel.grad.height, 
+      grid.rect(x = xs, y = ys, height = panel.grad.height,
                 width = panel.grad.width,
                 just = grad.just, default.units = "native",
                 gp = gpar(col = NA, fill = col.gradient))
@@ -377,9 +426,9 @@ panel.track.stats <-
                   default.units = "native",
                   gp = gpar(col = NA, fill = col.mean))
       } else if (box.fill == "gradient") {
-        grid.rect(x = box.xs, y = box.ys, height = box.grad.height, 
-                  width = box.grad.width, just = grad.just, 
-                  default.units = "native", 
+        grid.rect(x = box.xs, y = box.ys, height = box.grad.height,
+                  width = box.grad.width, just = grad.just,
+                  default.units = "native",
                   gp = gpar(col = NA, fill = col.gradient))
       }
     }
@@ -428,7 +477,7 @@ levelplot.track.stats <-
            legend = ddgram.legend(dd.row,  row.ord, dd.col,col.ord),
            colorkey = list(space = "left", at = colorkey.at),
            palette = colorRampPalette(rev(brewer.pal(11, "RdYlBu")),
-                                      interpolate = "spline", 
+                                      interpolate = "spline",
                                       space = "Lab")(100),
            ...)
 {
@@ -446,7 +495,7 @@ levelplot.track.stats <-
     norm.func <- normalize.track.stats
   }
   stats.norm <- norm.func(track.stats)
-  
+
   means <- stats.norm[, , "mean"]
   sds <- stats.norm[, , "sd"]
 
@@ -464,13 +513,13 @@ levelplot.track.stats <-
     means <- means[!mask.rows,]
     sds <- sds[!mask.rows,]
   }
-  
+
   if (threshold || is.null(sds) || sd.shape == "line") {
     z.range <- range(means, na.rm = TRUE)
   } else {
     z.range <- c(min(means, means - sds), max(means + sds))
   }
-  
+
   if (symmetric) {
     z.max <- max(abs(z.range))
     z.range <- c(-z.max, z.max)
@@ -511,7 +560,7 @@ levelplot.track.stats <-
             sd.shape = sd.shape,
             box.fill = box.fill,
             threshold = threshold,
-            xlab = xlab, 
+            xlab = xlab,
             ylab = ylab,
             at = colorkey.at,
             col.regions = palette,
@@ -527,7 +576,7 @@ load.track.stats <- function(filename, mnemonics = NULL,
                              ...) {
   if (gmtk) {
     read.func <- read.gmtk.track.stats
-    hierarchical <- is.hierarchical.gmtk(filename)
+    hierarchical <- is.truly.hierarchical.gmtk(filename)
   } else {
     read.func <- read.track.stats
     hierarchical <- FALSE
@@ -540,7 +589,7 @@ load.track.stats <- function(filename, mnemonics = NULL,
   } else {
     args$translations <- translations
   }
-  
+
   stats <- do.call(read.func, args)
 
   list(stats = stats, hierarchical = hierarchical)
@@ -554,7 +603,7 @@ plot.track.stats <- function(filename, symmetric = FALSE, ...) {
 save.track.stats <- function(dirpath, namebase, filename,
                              mnemonic_file = NULL,
                              translation_file = NULL,
-                             symmetric = FALSE, 
+                             symmetric = FALSE,
                              clobber = FALSE,
                              square.size = 15,  # px
                              ...) {
@@ -586,8 +635,12 @@ make.mnemonic.file <- function(infilename, outfilename, gmtk = FALSE, ...)
   stats <- as.stats.array(res$stats)
   stats.norm <- normalize.track.stats(stats)
   mnemonics <- generate.mnemonics(stats.norm, hierarchical = hierarchical, ...)
-  write.table(mnemonics, file = outfilename, quote = FALSE, 
+
+  con <- file(outfilename, "w")
+  write(paste("# mnemonic file generated by Segtools at", date()), con)
+  write.table(mnemonics, file = con, quote = FALSE,
               col.names = TRUE, row.names = FALSE, sep = "\t")
-  
+  close(con)
+
   outfilename
 }
