@@ -6,18 +6,15 @@ gmtk_parameters.py
 
 from __future__ import division, with_statement
 
-__version__ = "$Revision: 236 $"
-
+__version__ = "$Revision: 294 $"
 
 # A package-unique, descriptive module name used for filenames, etc
 # Must be the same as the folder containing this script
 MODULE = "gmtk_parameters"
 
-
 import os
 import sys
 
-
 from numpy import array
 
 from . import log
@@ -85,17 +82,18 @@ def validate(gmtk_file, dirpath, p_thresh=P_THRESH, q_thresh=Q_THRESH,
     if not os.path.isfile(gmtk_file):
         die("Could not find GMTK file: %s" % gmtk_file)
 
+    # XXX: why does this print "getbuffer" a few times? debug R
+    # read.gmtk.transition() code
     log("Loading gmtk transitions...", verbose, end="")
 
     labels, probs = load_gmtk_transitions(gmtk_file)
     log(" done", verbose)
 
-    # If mnemonics weren't specified, let's create a mnemonic file!
+    # If mnemonics weren't specified, let's create a mnemonic file
     if mnemonic_file is None and create_mnemonics:
-        mnemonic_file = create_mnemonic_file(gmtk_file, dirpath,
-                                             verbose=verbose,
-                                             clobber=clobber,
-                                             gmtk=True)
+        mnemonic_file = \
+            create_mnemonic_file(gmtk_file, dirpath, verbose=verbose,
+                                 clobber=clobber, gmtk=True)
 
     if not noplot:
         save_plot(dirpath, namebase=NAMEBASE, filename=gmtk_file,
@@ -150,7 +148,7 @@ def parse_options(args):
                      " Thus, all underscores could be converted to periods"
                      " with the single line: `_<TAB>.`. Mappings will be"
                      " applied sequentially, so a second line of:"
-                     " `.<TAB>#` would (together with the first line)"
+                     " `\\.<TAB>#` would (together with the first line)"
                      " convert all periods and underscores to pounds.")
     parser.add_option_group(group)
 
